@@ -260,6 +260,11 @@ def resample_data(dataframe, seed, blocks_length):
     return random_resample_data_by_blocks(dataframe, blocks_length)
 
 
+def calculate_intervals_from_p_values_and_alpha(distribution, p_values, alpha):
+    limits = calculate_limits_from_p_values_and_alpha(p_values, alpha)
+    return _calculate_intevals(distribution, limits)
+
+
 def calculate_limits_from_p_values_and_alpha(p_values, alpha):
     are_p_values_higher_of_alpha = (p_values[0] > alpha) and (p_values[1] > alpha)
     if are_p_values_higher_of_alpha:
